@@ -161,7 +161,9 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
         quit()
 
     if "Question_1_Answer_Unixtime" not in df_raw:
-        print("$$$$$$$$$$$$$$$$$$$$ {}".format(date_folder_path))
+        print("All Prompts are Never Prompted {}".format(date_folder_path))
+        quit()
+
     df_raw = df_raw[columns_list]
 
     if "Reprompt2_Prompt_UnixTime " in df_raw.columns:
